@@ -11,12 +11,19 @@ class Constellation(object):
     """Manage and analyze data from multiple pysat Instruments.
 
     Created as part of a Spring 2018 UTDesign project.
+
+    .. deprecated:: 2.3.0
+      The `name` kwarg was changed to `const_module` in pysat 3.0.0
+
     """
-    def __init__(self, instruments=None, name=None):
+    def __init__(self, instruments=None, name=None, const_module=None):
         """
         Constructs a Constellation given a list of instruments or the name of
         a file with a pre-defined constellation.
 
+        .. deprecated:: 2.3.0
+          The `name` kwarg was changed to `const_module` in pysat 3.0.0
+
         Parameters
         ----------
         instruments : list
@@ -24,13 +31,26 @@ class Constellation(object):
         name : string
             Name of a file in pysat/constellations containing a list of
             instruments.
+        const_module : string or NoneType
+            Name of a pysat constellation module (default=None)
 
         Note
         ----
         The name and instruments parameters should not both be set.
         If neither is given, an empty constellation will be created.
+
         """
 
+        # Raise warnings about deprecated kwargs/attributes
+        if name is None:
+            name = const_module
+        else:
+            dwarn = "".join(["Constellation attribute and kwarg input `name`",
+                             " has been renamed `const_module` in pysat ",
+                             "3.0.0"])
+            warnings.warn(dwarn, DeprecationWarning, stacklevel=2)
+
+        # Start initialization
         if instruments and name:
             raise ValueError('When creating a constellation, please specify '
                              'a list of instruments or a name, not both.')
@@ -45,6 +65,15 @@ class Constellation(object):
         else:
             self.instruments = []
 
+        if self.instruments and self.instruments[0].platform in ['icon',
+                                                                 'de2']:
+            warnings.warn(" ".join(["This constellation",
+                                    "has been removed from the pysat-managed",
+                                    "Instruments in pysat 3.0.0, and now",
+                                    "resides in pysatNASA:",
+                                    "https://github.com/pysat/pysatNASA"]),
+                          DeprecationWarning, stacklevel=2)
+
     def __getitem__(self, *args, **kwargs):
         """
         Look up a member Instrument by index.
