@@ -1,17 +1,22 @@
 # -*- coding: utf-8 -*-
 """Supports SuperMAG ground magnetometer measurements and SML/SMU indices.
 Downloading is supported; please follow their rules of the road:
-    http://supermag.jhuapl.edu/info/?page=rulesoftheroad
+http://supermag.jhuapl.edu/info/?page=rulesoftheroad
 
-Parameters
+.. deprecated:: 2.3.0
+  This Instrument module has been removed from pysat in the 3.0.0 release and
+  can now be found in pysatIncubator (https://github.com/pysat/pysatIncubator)
+
+Properties
 ----------
-platform : string
+platform
     'supermag'
-name : string
+name
     'magnetometer'
-tag : string
+tag
     Select  {'indices', '', 'all', 'stations'}
 
+
 Note
 ----
 Files must be downloaded from the website, and is freely available after
@@ -32,18 +37,17 @@ Warnings
   processing is available
 - Module not written by the SuperMAG team.
 
-Custom Functions
------------------
-
 """
 
 from __future__ import print_function, absolute_import
-import pandas as pds
+import functools
 import numpy as np
 from os import path
-import functools
+import re
 import warnings
 
+import pandas as pds
+
 import pysat
 
 platform = 'supermag'
@@ -58,21 +62,12 @@ _test_dates = {'': {kk: pysat.datetime(2009, 1, 1) for kk in tags.keys()}}
 
 def init(self):
     """Initializes the Instrument object with instrument specific values.
-
-    Runs once upon instantiation.
-
-    Parameters
-    ----------
-    self : pysat.Instrument
-        This object
-
-    Returns
-    --------
-    Void : (NoneType)
-        Object modified in place.
-
-
     """
+    warnings.warn("".join(["supermag_magnetometer has been removed from the ",
+                           "pysat-managed Instruments in pysat 3.0.0, and now",
+                           " resides in pysatIncubator: ",
+                           "https://github.com/pysat/pysatIncubator"]),
+                  DeprecationWarning, stacklevel=2)
 
     # if the tag is 'indices', update data_path to reflect this
     # both 'indices' and 'all' are stored under 'all'
@@ -103,28 +98,28 @@ def list_remote_files(tag='', sat_id=None, data_path=None, format_str=None,
 
     Parameters
     ----------
-    tag : (string)
+    tag : string
         Denotes type of file to load.  Accepted types are 'indices', 'all',
         'stations', and '' (for just magnetometer measurements).
         (default='')
-    sat_id : (string or NoneType)
+    sat_id : string or NoneType
         Specifies the satellite ID for a constellation.  Not used.
         (default=None)
-    data_path : (string or NoneType)
+    data_path : string or NoneType
         Path to data directory.  If None is specified, the value previously
         set in Instrument.files.data_path is used.  (default=None)
-    format_str : (string or NoneType)
+    format_str : string or NoneType
         User specified file format.  If None is specified, the default
         formats associated with the supplied tags are used. (default=None)
-    year : (int or NoneType)
+    year : int or NoneType
         Selects a given year to return remote files for.  None returns all
         years.
         (default=None)
-    month : (int or NoneType)
+    month : int or NoneType
         Selects a given month to return remote files for.  None returns all
         months.  Requires year to be defined.
         (default=None)
-    day : (int or NoneType)
+    day : int or NoneType
         Selects a given day to return remote files for.  None returns all
         days.  Requires year and month to be defined.
         (default=None)
@@ -177,22 +172,22 @@ def list_files(tag='', sat_id=None, data_path=None, format_str=None):
 
     Parameters
     -----------
-    tag : (string)
+    tag : string
         Denotes type of file to load.  Accepted types are 'indices', 'all',
         'stations', and '' (for just magnetometer measurements). (default='')
-    sat_id : (string or NoneType)
+    sat_id : string or NoneType
         Specifies the satellite ID for a constellation.  Not used.
         (default=None)
-    data_path : (string or NoneType)
+    data_path : string or NoneType
         Path to data directory.  If None is specified, the value previously
         set in Instrument.files.data_path is used.  (default=None)
-    format_str : (string or NoneType)
+    format_str : string or NoneType
         User specified file format.  If None is specified, the default
         formats associated with the supplied tags are used. (default=None)
 
     Returns
     --------
-    pysat.Files.from_os : (pysat._files.Files)
+    pysat.Files.from_os : pysat._files.Files
         A pandas Series containing the verified available files
 
     """
@@ -249,19 +244,19 @@ def load(fnames, tag='', sat_id=None):
 
     Parameters
     -----------
-    fnames : (list)
+    fnames : list
         List of filenames
-    tag : (str)
+    tag : str
         Denotes type of file to load.  Accepted types are 'indices', 'all',
         'stations', and '' (for just magnetometer measurements). (default='')
-    sat_id : (str or NoneType)
+    sat_id : str or NoneType
         Satellite ID for constellations, not used. (default=None)
 
     Returns
     --------
-    data : (pandas.DataFrame)
+    data : pandas.DataFrame
         Object containing satellite data
-    meta : (pysat.Meta)
+    meta : pysat.Meta
         Object containing metadata such as column names and units
 
     """
@@ -314,21 +309,29 @@ def load(fnames, tag='', sat_id=None):
 def load_csv_data(fname, tag):
     """Load data from a comma separated SuperMAG file
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and will be accessible
+      in pysatIncubator
+
     Parameters
     ------------
-    fname : (str)
+    fname : str
         CSV SuperMAG file name
-    tag : (str)
+    tag : str
         Denotes type of file to load.  Accepted types are 'indices', 'all',
         'stations', and '' (for just magnetometer measurements).
 
     Returns
     --------
-    data : (pandas.DataFrame)
+    data : pandas.DataFrame
         Pandas DataFrame
 
     """
-    import re
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "pysatIncubator: ",
+                           "https://github.com/pysat/pysatIncubator"]),
+                  DeprecationWarning, stacklevel=2)
 
     if tag == "stations":
         # Because there may be multiple operators, the default pandas reader
@@ -380,24 +383,33 @@ def load_csv_data(fname, tag):
 def load_ascii_data(fname, tag):
     """Load data from a self-documenting ASCII SuperMAG file
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and will be accessible
+      in pysatIncubator
+
     Parameters
     ------------
-    fname : (str)
+    fname : str
         ASCII SuperMAG filename
-    tag : (str)
+    tag : str
         Denotes type of file to load.  Accepted types are 'indices', 'all',
         'stations', and '' (for just magnetometer measurements).
 
     Returns
     --------
-    data : (pandas.DataFrame)
+    data : pandas.DataFrame
         Pandas DataFrame
-    baseline : (list)
+    baseline : list
         List of strings denoting the presence of a standard and file-specific
         baselines for each file.  None of not present or not applicable.
 
     """
-    import re
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "pysatIncubator: ",
+                           "https://github.com/pysat/pysatIncubator"]),
+                  DeprecationWarning, stacklevel=2)
+
     ndata = {"indices": 2, "": 4, "all": 4, "stations": 8}
     dkeys = {'stations': list(), '': ['IAGA', 'N', 'E', 'Z']}
     data = pds.DataFrame(None)
@@ -537,17 +549,26 @@ def load_ascii_data(fname, tag):
 def update_smag_metadata(col_name):
     """Update SuperMAG metadata
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and will be accessible
+      in pysatIncubator
+
     Parameters
     -----------
-    col_name : (str)
+    col_name : str
         Data column name
 
     Returns
     --------
-    col_dict : (dict)
+    col_dict : dict
        Dictionary of strings detailing the units and long-form name of the data
 
     """
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "pysatIncubator: ",
+                           "https://github.com/pysat/pysatIncubator"]),
+                  DeprecationWarning, stacklevel=2)
 
     smag_units = {'IAGA': 'none', 'N': 'nT', 'E': 'nT', 'Z': 'nT',
                   'MLT': 'hours', 'MLAT': 'degrees', 'SZA': 'degrees',
@@ -619,18 +640,27 @@ def format_baseline_list(baseline_list):
     """Format the list of baseline information from the loaded files into a
     cohesive, informative string
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and will be accessible
+      in pysatIncubator
+
     Parameters
     ------------
-    baseline_list : (list)
+    baseline_list : list
         List of strings specifying the baseline information for each
         SuperMAG file
 
     Returns
     ---------
-    base_string : (str)
+    base_string : str
         Single string containing the relevent data
 
     """
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "pysatIncubator: ",
+                           "https://github.com/pysat/pysatIncubator"]),
+                  DeprecationWarning, stacklevel=2)
 
     uniq_base = dict()
     uniq_delta = dict()
@@ -703,6 +733,10 @@ def download(date_array):
 def append_data(file_strings, file_fmt, tag):
     """ Load the SuperMAG files
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and will be accessible
+      in pysatIncubator
+
     Parameters
     -----------
     file_strings : array-like
@@ -719,6 +753,12 @@ def append_data(file_strings, file_fmt, tag):
         String with all data, ready for output to a file
 
     """
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "pysatIncubator: ",
+                           "https://github.com/pysat/pysatIncubator"]),
+                  DeprecationWarning, stacklevel=2)
+
     # Determine the right appending routine for the file type
     if file_fmt.lower() == "csv":
         return append_csv_data(file_strings)
@@ -729,6 +769,10 @@ def append_data(file_strings, file_fmt, tag):
 def append_ascii_data(file_strings, tag):
     """ Append data from multiple files for the same time period
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and will be accessible
+      in pysatIncubator
+
     Parameters
     -----------
     file_strings : array-like
@@ -743,7 +787,11 @@ def append_ascii_data(file_strings, tag):
         String with all data, ready for output to a file
 
     """
-    import re
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "pysatIncubator: ",
+                           "https://github.com/pysat/pysatIncubator"]),
+                  DeprecationWarning, stacklevel=2)
 
     # Start with data from the first list element
     out_lines = file_strings[0].split('\n')
@@ -841,6 +889,10 @@ def append_ascii_data(file_strings, tag):
 def append_csv_data(file_strings):
     """ Append data from multiple csv files for the same time period
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and will be accessible
+      in pysatIncubator
+
     Parameters
     -----------
     file_strings : array-like
@@ -852,6 +904,12 @@ def append_csv_data(file_strings):
         String with all data, ready for output to a file
 
     """
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "pysatIncubator: ",
+                           "https://github.com/pysat/pysatIncubator"]),
+                  DeprecationWarning, stacklevel=2)
+
     # Start with data from the first list element
     out_lines = list()
     head_line = None
