@@ -1,19 +1,24 @@
 # -*- coding: utf-8 -*-
 """Supports F10.7 index values. Downloads data from LASP and the SWPC.
 
-Parameters
+.. deprecated:: 2.3.0
+  This Instrument module has been removed from pysat in the 3.0.0 release and
+  can now be found in pysatSpaceWeather
+  (https://github.com/pysat/pysatSpaceWeather)
+
+Properties
 ----------
-platform : string
+platform
     'sw'
-name : string
+name
     'f107'
-tag : string
-    '' LASP F10.7 data (downloads by month, loads by day)
-    'all' All LASP standard F10.7
-    'prelim' Preliminary SWPC daily solar indices
-    'daily' Daily SWPC solar indices (contains last 30 days)
-    'forecast' Grab forecast data from SWPC (next 3 days)
-    '45day' 45-Day Forecast data from the Air Force
+tag
+    - '' : LASP F10.7 data (downloads by month, loads by day)
+    - 'all' : All LASP standard F10.7
+    - 'prelim' : Preliminary SWPC daily solar indices
+    - 'daily' : Daily SWPC solar indices (contains last 30 days)
+    - 'forecast' : Grab forecast data from SWPC (next 3 days)
+    - '45day' : 45-Day Forecast data from the Air Force
 
 Note
 ----
@@ -23,6 +28,7 @@ for the current day. When loading forecast data, the date specified with the
 load command is the date the forecast was generated. The data loaded will span
 three days. To always ensure you are loading the most recent data, load
 the data with tomorrow's date.
+::
 
     f107 = pysat.Instrument('sw', 'f107', tag='forecast')
     f107.download()
@@ -30,9 +36,10 @@ the data with tomorrow's date.
 
 
 
-The forecast data should not be used with the data padding option available
-from pysat.Instrument objects. The 'all' tag shouldn't be used either, no
-other data available to pad with.
+The forecast or prelim data should not be used with the data padding option
+available from pysat.Instrument objects. The 'all' tag shouldn't be used either,
+no other data available to pad with.
+
 
 Warnings
 --------
@@ -50,6 +57,9 @@ import pandas as pds
 
 import pysat
 
+import logging
+logger = logging.getLogger(__name__)
+
 platform = 'sw'
 name = 'f107'
 tags = {'': 'Daily LASP value of F10.7',
@@ -67,11 +77,24 @@ today = pysat.datetime(now.year, now.month, now.day)
 tomorrow = today + pds.DateOffset(days=1)
 # set test dates
 _test_dates = {'': {'': pysat.datetime(2009, 1, 1),
-                   'all': pysat.datetime(2009, 1, 1),
-                   'prelim': pysat.datetime(2009, 1, 1),
-                   'daily': tomorrow,
-                   'forecast': tomorrow,
-                   '45day': tomorrow}}
+                    'all': pysat.datetime(2009, 1, 1),
+                    'prelim': pysat.datetime(2009, 1, 1),
+                    'daily': tomorrow,
+                    'forecast': tomorrow,
+                    '45day': tomorrow}}
+
+
+def init(self):
+    """Initializes the Instrument object
+    """
+
+    warnings.warn("".join(["sw_f107 has been removed from the pysat-managed ",
+                           "Instruments in pysat 3.0.0, and now resides in ",
+                           "pysatSpaceWeather: ",
+                           "https://github.com/pysat/pysatSpaceWeather"]),
+                  DeprecationWarning, stacklevel=2)
+
+    return
 
 
 def load(fnames, tag=None, sat_id=None):
@@ -79,18 +102,18 @@ def load(fnames, tag=None, sat_id=None):
 
     Parameters
     ------------
-    fnames : (pandas.Series)
+    fnames : pandas.Series
         Series of filenames
-    tag : (str or NoneType)
+    tag : str or NoneType
         tag or None (default=None)
-    sat_id : (str or NoneType)
+    sat_id : str or NoneType
         satellite id or None (default=None)
 
     Returns
     ---------
-    data : (pandas.DataFrame)
+    data : pandas.DataFrame
         Object containing satellite data
-    meta : (pysat.Meta)
+    meta : pysat.Meta
         Object containing metadata such as column names and units
 
     Notes
@@ -173,22 +196,22 @@ def list_files(tag=None, sat_id=None, data_path=None, format_str=None):
 
     Parameters
     -----------
-    tag : (string or NoneType)
+    tag : string or NoneType
         Denotes type of file to load.
         (default=None)
-    sat_id : (string or NoneType)
+    sat_id : string or NoneType
         Specifies the satellite ID for a constellation.  Not used.
         (default=None)
-    data_path : (string or NoneType)
+    data_path : string or NoneType
         Path to data directory.  If None is specified, the value previously
         set in Instrument.files.data_path is used.  (default=None)
-    format_str : (string or NoneType)
+    format_str : string or NoneType
         User specified file format.  If None is specified, the default
         formats associated with the supplied tags are used. (default=None)
 
     Returns
     --------
-    pysat.Files.from_os : (pysat._files.Files)
+    pysat.Files.from_os : pysat._files.Files
         A class containing the verified available files
 
     Notes
@@ -196,7 +219,6 @@ def list_files(tag=None, sat_id=None, data_path=None, format_str=None):
     Called by pysat. Not intended for direct use by user.
 
     """
-    import time
 
     if data_path is not None:
         if tag == '':
@@ -240,8 +262,7 @@ def list_files(tag=None, sat_id=None, data_path=None, format_str=None):
 
         elif tag == 'prelim':
             # files are by year (and quarter). The load routine will load a
-            # year of data and use the appended date to select out appropriate
-            # data.
+            # year of data
             if format_str is None:
                 format_str = \
                     'f107_prelim_{year:04d}_{month:02d}_v{version:01d}.txt'
@@ -330,21 +351,16 @@ def download(date_array, tag, sat_id, data_path, user=None, password=None):
 
     Parameters
     -----------
-    tag : (string or NoneType)
+    tag : string or NoneType
         Denotes type of file to load.  Accepted types are '' and 'forecast'.
         (default=None)
-    sat_id : (string or NoneType)
+    sat_id : string or NoneType
         Specifies the satellite ID for a constellation.  Not used.
         (default=None)
-    data_path : (string or NoneType)
+    data_path : string or NoneType
         Path to data directory.  If None is specified, the value previously
         set in Instrument.files.data_path is used.  (default=None)
 
-    Returns
-    --------
-    Void : (NoneType)
-        data downloaded to disk, if available.
-
     Note
     ----
     Called by pysat. Not intended for direct use by user.
@@ -497,7 +513,7 @@ def download(date_array, tag, sat_id, data_path, user=None, password=None):
                         ftp.retrbinary('RETR ' + fname,
                                        open(saved_fname, 'wb').write)
                         downloaded = True
-                        print('Downloaded file for ' + date.strftime('%x'))
+                        logger.info('Downloaded file for ' + date.strftime('%x'))
 
                     except ftplib.error_perm as exception:
                         # Could not fetch, so cannot rewrite
@@ -521,7 +537,7 @@ def download(date_array, tag, sat_id, data_path, user=None, password=None):
                     break
 
             if not downloaded:
-                print('File not available for {:}'.format(date.strftime('%x')))
+                logger.info('File not available for {:}'.format(date.strftime('%x')))
             elif rewritten:
                 with open(saved_fname, 'r') as fprelim:
                     lines = fprelim.read()
@@ -537,7 +553,7 @@ def download(date_array, tag, sat_id, data_path, user=None, password=None):
 
     elif tag == 'daily':
         import requests
-        print('This routine can only download the latest 30 day file')
+        logger.info('This routine can only download the latest 30 day file')
 
         # download webpage
         furl = 'https://services.swpc.noaa.gov/text/daily-solar-indices.txt'
@@ -550,7 +566,7 @@ def download(date_array, tag, sat_id, data_path, user=None, password=None):
 
     elif tag == 'forecast':
         import requests
-        print('This routine can only download the current forecast, not ' +
+        logger.info('This routine can only download the current forecast, not ' +
               'archived forecasts')
         # download webpage
         furl = 'https://services.swpc.noaa.gov/text/' + \
@@ -580,7 +596,7 @@ def download(date_array, tag, sat_id, data_path, user=None, password=None):
 
     elif tag == '45day':
         import requests
-        print('This routine can only download the current forecast, not ' +
+        logger.info('This routine can only download the current forecast, not ' +
               'archived forecasts')
         # download webpage
         furl = 'https://services.swpc.noaa.gov/text/45-day-ap-forecast.txt'
@@ -620,20 +636,31 @@ def parse_45day_block(block_lines):
     """ Parse the data blocks used in the 45-day Ap and F10.7 Flux Forecast
     file
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and will be accessible
+      in `pysatSpaceWeather.instruments.sw_f107.parse_45day_block`
+
     Parameters
     ----------
-    block_lines : (list)
+    block_lines : list
         List of lines containing data in this data block
 
     Returns
     -------
-    dates : (list)
+    dates : list
         List of dates for each date/data pair in this block
-    values : (list)
+    values : list
         List of values for each date/data pair in this block
 
     """
 
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "`pysatSpaceWeather.instruments.sw_f107.",
+                           "parse_45day_block` instead: ",
+                           "https://github.com/pysat/pysatSpaceWeather"]),
+                  DeprecationWarning, stacklevel=2)
+
     # Initialize the output
     dates = list()
     values = list()
@@ -656,24 +683,27 @@ def parse_45day_block(block_lines):
 def rewrite_daily_file(year, outfile, lines):
     """ Rewrite the SWPC Daily Solar Data files
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and will be accessible
+      in `pysatSpaceWeather.instruments.sw_f107.rewrite_daily_file`
+
     Parameters
     ----------
-    year : (int)
+    year : int
         Year of data file (format changes based on date)
-    outfile : (str)
+    outfile : str
         Output filename
-    lines : (str)
+    lines : str
         String containing all output data (result of 'read')
 
-    Returns
-    -------
-    Void
-
     """
 
-    # Parse text to get the date the prediction was generated
-    date_str = lines.split(':Issued: ')[-1].split('\n')[0]
-    date = pysat.datetime.strptime(date_str, '%H%M UT %d %b %Y')
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "`pysatSpaceWeather.instruments.sw_f107.",
+                           "rewrite_daily_file` instead: ",
+                           "https://github.com/pysat/pysatSpaceWeather"]),
+                  DeprecationWarning, stacklevel=2)
 
     # get to the solar index data
     if year > 2000:
@@ -704,24 +734,35 @@ def rewrite_daily_file(year, outfile, lines):
 def parse_daily_solar_data(data_lines, year, optical):
     """ Parse the data in the SWPC daily solar index file
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and will be accessible
+      in `pysatSpaceWeather.instruments.sw_f107.parse_daily_solar_data`
+
     Parameters
     ----------
-    data_lines : (list)
+    data_lines : list
         List of lines containing data
-    year : (list)
+    year : list
         Year of file
-    optical : (boolean)
+    optical : boolean
         Flag denoting whether or not optical data is available
 
     Returns
     -------
-    dates : (list)
+    dates : list
         List of dates for each date/data pair in this block
-    values : (dict)
+    values : dict
         Dict of lists of values, where each key is the value name
 
     """
 
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "`pysatSpaceWeather.instruments.sw_f107.",
+                           "parse_daily_solar_data` instead: ",
+                           "https://github.com/pysat/pysatSpaceWeather"]),
+                  DeprecationWarning, stacklevel=2)
+
     # Initialize the output
     dates = list()
     val_keys = ['f107', 'ssn', 'ss_area', 'new_reg', 'smf', 'goes_bgd_flux',
@@ -767,15 +808,19 @@ def parse_daily_solar_data(data_lines, year, optical):
 def calc_f107a(f107_inst, f107_name='f107', f107a_name='f107a', min_pnts=41):
     """ Calculate the 81 day mean F10.7
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and will be accessible
+      in `pysatSpaceWeather.instruments.sw_f107.calc_f107a`
+
     Parameters
     ----------
-    f107_inst : (pysat.Instrument)
+    f107_inst : pysat.Instrument
         pysat Instrument holding the F10.7 data
-    f107_name : (str)
+    f107_name : str
         Data column name for the F10.7 data (default='f107')
-    f107a_name : (str)
+    f107a_name : str
         Data column name for the F10.7a data (default='f107a')
-    min_pnts : (int)
+    min_pnts : int
         Minimum number of points required to calculate an average (default=41)
 
     Returns
@@ -788,6 +833,13 @@ def calc_f107a(f107_inst, f107_name='f107', f107a_name='f107a', min_pnts=41):
 
     """
 
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "`pysatSpaceWeather.instruments.sw_f107.",
+                           "calc_f107a` instead: ",
+                           "https://github.com/pysat/pysatSpaceWeather"]),
+                  DeprecationWarning, stacklevel=2)
+
     # Test to see that the input data is present
     if f107_name not in f107_inst.data.columns:
         raise ValueError("unknown input data column: " + f107_name)
