@@ -1,16 +1,22 @@
 # -*- coding: utf-8 -*-
 """Supports Kp index values. Downloads data from ftp.gfz-potsdam.de or SWPC.
 
+.. deprecated:: 2.3.0
+  This Instrument module has been removed from pysat in the 3.0.0 release and
+  can now be found in pysatSpaceWeather
+  (https://github.com/pysat/pysatSpaceWeather)
+
+
 Parameters
 ----------
-platform : string
+platform
     'sw'
-name : string
+name
     'kp'
-tag : string
-    '' Standard Kp data
-    'forecast' Grab forecast data from SWPC (next 3 days)
-    'recent' Grab last 30 days of Kp data from SWPC
+tag
+    - '' : Standard Kp data
+    - 'forecast' : Grab forecast data from SWPC (next 3 days)
+    - 'recent' : Grab last 30 days of Kp data from SWPC
 
 Note
 ----
@@ -24,6 +30,7 @@ for the current day. When loading forecast data, the date specified with the
 load command is the date the forecast was generated. The data loaded will span
 three days. To always ensure you are loading the most recent data, load
 the data with tomorrow's date.
+::
 
     kp = pysat.Instrument('sw', 'kp', tag='recent')
     kp.download()
@@ -36,6 +43,7 @@ to the generation date.
 The recent and forecast data should not be used with the data padding option
 available from pysat.Instrument objects.
 
+
 Warnings
 --------
 The 'forecast' Kp data loads three days at a time. The data padding feature
@@ -50,16 +58,25 @@ Any opinions, findings, and conclusions or recommendations expressed in this
 material are those of the author(s) and do not necessarily reflect the views
 of the National Science Foundation.
 
+Custom Functions
+----------------
+filter_geoquiet
+    Filters pysat.Instrument data for given time after Kp drops below gate.
+
 """
 
 import functools
 import numpy as np
 import os
+import warnings
 
 import pandas as pds
 
 import pysat
 
+import logging
+logger = logging.getLogger(__name__)
+
 
 platform = 'sw'
 name = 'kp'
@@ -73,7 +90,20 @@ now = pysat.datetime.now()
 today = pysat.datetime(now.year, now.month, now.day)
 # set test dates
 _test_dates = {'': {'': pysat.datetime(2009, 1, 1),
-                   'forecast': today + pds.DateOffset(days=1)}}
+                    'forecast': today + pds.DateOffset(days=1)}}
+
+
+def init(self):
+    """Initializes the Instrument object
+    """
+
+    warnings.warn("".join(["sw_kp has been removed from the pysat-managed ",
+                           "Instruments in pysat 3.0.0, and now resides in ",
+                           "pysatSpaceWeather: ",
+                           "https://github.com/pysat/pysatSpaceWeather"]),
+                  DeprecationWarning, stacklevel=2)
+
+    return
 
 
 def load(fnames, tag=None, sat_id=None):
@@ -81,18 +111,18 @@ def load(fnames, tag=None, sat_id=None):
 
     Parameters
     ------------
-    fnames : (pandas.Series)
+    fnames : pandas.Series
         Series of filenames
-    tag : (str or NoneType)
+    tag : str or NoneType
         tag or None (default=None)
-    sat_id : (str or NoneType)
+    sat_id : str or NoneType
         satellite id or None (default=None)
 
     Returns
     ---------
-    data : (pandas.DataFrame)
+    data : pandas.DataFrame
         Object containing satellite data
-    meta : (pysat.Meta)
+    meta : pysat.Meta
         Object containing metadata such as column names and units
 
     Notes
@@ -176,22 +206,22 @@ def list_files(tag=None, sat_id=None, data_path=None, format_str=None):
 
     Parameters
     -----------
-    tag : (string or NoneType)
+    tag : string or NoneType
         Denotes type of file to load.
         (default=None)
-    sat_id : (string or NoneType)
+    sat_id : string or NoneType
         Specifies the satellite ID for a constellation.  Not used.
         (default=None)
-    data_path : (string or NoneType)
+    data_path : string or NoneType
         Path to data directory.  If None is specified, the value previously
         set in Instrument.files.data_path is used.  (default=None)
-    format_str : (string or NoneType)
+    format_str : string or NoneType
         User specified file format.  If None is specified, the default
         formats associated with the supplied tags are used. (default=None)
 
     Returns
     --------
-    pysat.Files.from_os : (pysat._files.Files)
+    pysat.Files.from_os : pysat._files.Files
         A class containing the verified available files
 
     Notes
@@ -251,21 +281,16 @@ def download(date_array, tag, sat_id, data_path, user=None, password=None):
 
     Parameters
     -----------
-    tag : (string or NoneType)
+    tag : string or NoneType
         Denotes type of file to load.  Accepted types are '' and 'forecast'.
         (default=None)
-    sat_id : (string or NoneType)
+    sat_id : string or NoneType
         Specifies the satellite ID for a constellation.  Not used.
         (default=None)
-    data_path : (string or NoneType)
+    data_path : string or NoneType
         Path to data directory.  If None is specified, the value previously
         set in Instrument.files.data_path is used.  (default=None)
 
-    Returns
-    --------
-    Void : (NoneType)
-        data downloaded to disk, if available.
-
     Note
     ----
     Called by pysat. Not intended for direct use by user.
@@ -294,7 +319,7 @@ def download(date_array, tag, sat_id, data_path, user=None, password=None):
             saved_fname = os.path.join(data_path, local_fname)
             if not fname in dnames:
                 try:
-                    print('Downloading file for '+date.strftime('%b %Y'))
+                    logger.info('Downloading file for '+date.strftime('%b %Y'))
                     sys.stdout.flush()
                     ftp.retrbinary('RETR '+fname, open(saved_fname, 'wb').write)
                     dnames.append(fname)
@@ -312,13 +337,13 @@ def download(date_array, tag, sat_id, data_path, user=None, password=None):
                         # file isn't actually there, just let people know
                         # then continue on
                         os.remove(saved_fname)
-                        print('File not available for '+date.strftime('%x'))
+                        logger.info('File not available for '+date.strftime('%x'))
 
         ftp.close()
 
     elif tag == 'forecast':
         import requests
-        print('This routine can only download the current forecast, ' +
+        logger.info('This routine can only download the current forecast, ' +
               'not archived forecasts')
         # download webpage
         furl = 'https://services.swpc.noaa.gov/text/3-day-geomag-forecast.txt'
@@ -357,7 +382,7 @@ def download(date_array, tag, sat_id, data_path, user=None, password=None):
 
     elif tag == 'recent':
         import requests
-        print('This routine can only download the current webpage, not ' +
+        logger.info('This routine can only download the current webpage, not ' +
               'archived forecasts')
         # download webpage
         rurl = 'https://services.swpc.noaa.gov/text/' + \
@@ -401,6 +426,12 @@ def filter_geoquiet(sat, maxKp=None, filterTime=None, kpData=None,
                     kp_inst=None):
     """Filters pysat.Instrument data for given time after Kp drops below gate.
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and has been replaced
+      with the more adaptable function,
+      `pysatSpaceWeather.instruments.methods.kp_ap.filter_geomag`. Be sure to
+      update to use the new kwargs.
+
     Parameters
     ----------
     sat : pysat.Instrument
@@ -415,11 +446,6 @@ def filter_geoquiet(sat, maxKp=None, filterTime=None, kpData=None,
     kp_inst : pysat.Instrument (optional)
         Kp pysat.Instrument object ready to load Kp data.Overrides kpData.
 
-    Returns
-    -------
-    None : NoneType
-        sat Instrument object modified in place
-
     Notes
     -----
     Loads Kp data for the same timeframe covered by sat and sets sat.data to
@@ -430,6 +456,14 @@ def filter_geoquiet(sat, maxKp=None, filterTime=None, kpData=None,
     data.
 
     """
+
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "`pysatSpaceWeather.instruments.methods.kp_ap.",
+                           "filter_geomag` instead: ",
+                           "https://github.com/pysat/pysatSpaceWeather"]),
+                  DeprecationWarning, stacklevel=2)
+
     if kp_inst is not None:
         kp_inst.load(date=sat.date, verifyPad=True)
         kpData = kp_inst
@@ -461,23 +495,28 @@ def filter_geoquiet(sat, maxKp=None, filterTime=None, kpData=None,
 def initialize_kp_metadata(meta, data_key, fill_val=-1):
     """ Initialize the Kp meta data using our knowledge of the index
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and has been replaced
+      with `pysatSpaceWeather.instruments.methods.kp_ap.initialize_kp_metadata`
+
     Parameters
     ----------
-    meta : (pysat._meta.Meta)
+    meta : pysat._meta.Meta
         Pysat Metadata
-    data_key : (str)
+    data_key : str
         String denoting the data key
-    fill_val : (int or float)
+    fill_val : int or float
         File-specific fill value (default=-1)
 
-    Returns
-    -------
-    Void
-
-    Updates metadata
-
     """
 
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "`pysatSpaceWeather.instruments.methods.kp_ap.",
+                           "initialize_kp_metadata` instead: ",
+                           "https://github.com/pysat/pysatSpaceWeather"]),
+                  DeprecationWarning, stacklevel=2)
+
     data_label = data_key.replace("_", " ")
     format_label = data_label[0].upper() + data_label[1:]
 
@@ -494,9 +533,13 @@ def initialize_kp_metadata(meta, data_key, fill_val=-1):
 def convert_3hr_kp_to_ap(kp_inst):
     """ Calculate 3 hour ap from 3 hour Kp index
 
+    .. deprecated:: 2.3.0
+      This routine has been deprecated in pysat 3.0.0, and has been replaced
+      with `pysatSpaceWeather.instruments.methods.kp_ap.convert_3hr_kp_to_ap`
+
     Parameters
     ----------
-    kp_inst : (pysat.Instrument)
+    kp_inst : pysat.Instrument
         Pysat instrument containing Kp data
 
     Returns
@@ -510,6 +553,13 @@ def convert_3hr_kp_to_ap(kp_inst):
 
     """
 
+    warnings.warn("".join(["This function is deprecated here and will be ",
+                           "removed in pysat 3.0.0. Please use ",
+                           "`pysatSpaceWeather.instruments.methods.kp_ap.",
+                           "convert_3hr_kp_to_ap` instead: ",
+                           "https://github.com/pysat/pysatSpaceWeather"]),
+                  DeprecationWarning, stacklevel=2)
+
     # Kp are keys, where n.3 = n+ and n.6 = (n+1)-. E.g., 0.6 = 1-
     kp_to_ap = {0: 0, 0.3: 2, 0.6: 3, 1: 4, 1.3: 5, 1.6: 6, 2: 7, 2.3: 9,
                 2.6: 12, 3: 15, 3.3: 18, 3.6: 22, 4: 27, 4.3: 32, 4.6: 39,
