@@ -1,10 +1,15 @@
 # -*- coding: utf-8 -*-
-from __future__ import print_function
-from __future__ import absolute_import
 """
 Instrument independent seasonal averaging routine. Supports averaging
 1D and 2D data.
+
+.. deprecated:: 2.2.0
+  `ssnl.avg` will be removed in pysat 3.0.0, it will be added to pysatSeasons:
+  https://github.com/pysat/pysatSeasons
+
 """
+from __future__ import print_function
+from __future__ import absolute_import
 
 import pysat
 import numpy as np
@@ -16,6 +21,10 @@ import warnings
 def median1D(const, bin1, label1, data_label, auto_bin=True, returnData=False):
     """Return a 1D median of data_label over a season and label1
 
+    .. deprecated:: 2.2.0
+      `median1D` will be removed in pysat 3.0.0, it will
+      be added to pysatSeasons
+
     Parameters
     ----------
     const: Constellation or Instrument
@@ -42,7 +51,7 @@ def median1D(const, bin1, label1, data_label, auto_bin=True, returnData=False):
 
     """
 
-    warnings.warn(' '.join(["This function is deprecated here and will be",
+    warnings.warn(' '.join(["`median1D` is deprecated here and will be",
                             "removed in pysat 3.0.0. Please use",
                             "pysatSeasons instead:"
                             "https://github.com/pysat/pysatSeasons"]),
@@ -53,10 +62,14 @@ def median1D(const, bin1, label1, data_label, auto_bin=True, returnData=False):
     # If it's a Constellation, then we can do that as is, but if it's
     #  an Instrument, we just have to put that Instrument into something
     #  that will yeild that Instrument, like a list.
-    if isinstance(const, pysat.Instrument):
+    if str(type(const)) == str(type(pysat.Instrument())):
         const = [const]
-    elif not isinstance(const, pysat.Constellation):
-        raise ValueError("Parameter must be an Instrument or a Constellation.")
+    elif not (str(type(const)) == str(type(pysat.Constellation()))):
+        estr = ''.join(("Parameter must be an Instrument or a Constellation.",
+                        " Received: ", str(type(const)),
+                        str(type(pysat.Instrument())),
+                        str(type(pysat.Constellation()))))
+        raise ValueError(estr)
 
     # create bins
     # seems to create the boundaries used for sorting into bins
@@ -110,6 +123,10 @@ def median2D(const, bin1, label1, bin2, label2, data_label,
              returnData=False, auto_bin=True):
     """Return a 2D average of data_label over a season and label1, label2.
 
+    .. deprecated:: 2.2.0
+      `median2D` will be removed in pysat 3.0.0, it will
+      be added to pysatSeasons
+
     Parameters
     ----------
         const: Constellation or Instrument
@@ -131,7 +148,7 @@ def median2D(const, bin1, label1, bin2, label2, data_label,
 
     """
 
-    warnings.warn(' '.join(["This function is deprecated here and will be",
+    warnings.warn(' '.join(["`median2D` is deprecated here and will be",
                             "removed in pysat 3.0.0. Please use",
                             "pysatSeasons instead:"
                             "https://github.com/pysat/pysatSeasons"]),
@@ -142,10 +159,14 @@ def median2D(const, bin1, label1, bin2, label2, data_label,
     # If it's a Constellation, then we can do that as is, but if it's
     #  an Instrument, we just have to put that Instrument into something
     #  that will yeild that Instrument, like a list.
-    if isinstance(const, pysat.Instrument):
+    if str(type(const)) == str(type(pysat.Instrument())):
         const = [const]
-    elif not isinstance(const, pysat.Constellation):
-        raise ValueError("Parameter must be an Instrument or a Constellation.")
+    elif not (str(type(const)) == str(type(pysat.Constellation()))):
+        estr = ''.join(("Parameter must be an Instrument or a Constellation.",
+                        " Received: ", str(type(const)),
+                        str(type(pysat.Instrument())),
+                        str(type(pysat.Constellation()))))
+        raise ValueError(estr)
 
     # create bins
     # seems to create the boundaries used for sorting into bins
@@ -215,6 +236,19 @@ def median2D(const, bin1, label1, bin2, label2, data_label,
 
 def _calc_2d_median(ans, data_label, binx, biny, xarr, yarr, zarr, numx,
                     numy, numz, returnData=False):
+    """Calculate 2D Medians
+
+    .. deprecated:: 2.2.0
+      Routine will be removed in pysat 3.0.0, it will be added to pysatSeasons:
+      https://github.com/pysat/pysatSeasons
+
+    """
+
+    warnings.warn(' '.join(["`_calc_2d_median` is deprecated here and will be",
+                            "removed in pysat 3.0.0. Please use",
+                            "pysatSeasons instead:"
+                            "https://github.com/pysat/pysatSeasons"]),
+                  DeprecationWarning, stacklevel=2)
 
     # set up output arrays
     medianAns = [[[None for i in xarr] for j in yarr] for k in zarr]
@@ -328,6 +362,10 @@ def _calc_2d_median(ans, data_label, binx, biny, xarr, yarr, zarr, numx,
 def mean_by_day(inst, data_label):
     """Mean of data_label by day over Instrument.bounds
 
+    .. deprecated:: 2.2.0
+      `mean_by_day` will be removed in pysat 3.0.0, it will
+      be added to pysatSeasons
+
     Parameters
     ----------
     data_label : string
@@ -340,7 +378,7 @@ def mean_by_day(inst, data_label):
 
     """
 
-    warnings.warn(' '.join(["This function is deprecated here and will be",
+    warnings.warn(' '.join(["`_calc_2d_median` is deprecated here and will be",
                             "removed in pysat 3.0.0. Please use",
                             "pysatSeasons instead:"
                             "https://github.com/pysat/pysatSeasons"]),
@@ -352,6 +390,10 @@ def mean_by_day(inst, data_label):
 def mean_by_orbit(inst, data_label):
     """Mean of data_label by orbit over Instrument.bounds
 
+    .. deprecated:: 2.2.0
+      `mean_by_orbit` will be removed in pysat 3.0.0, it will
+      be added to pysatSeasons
+
     Parameters
     ----------
     data_label : string
@@ -364,7 +406,7 @@ def mean_by_orbit(inst, data_label):
 
     """
 
-    warnings.warn(' '.join(["This function is deprecated here and will be",
+    warnings.warn(' '.join(["`mean_by_orbit` is deprecated here and will be",
                             "removed in pysat 3.0.0. Please use",
                             "pysatSeasons instead:"
                             "https://github.com/pysat/pysatSeasons"]),
@@ -376,6 +418,10 @@ def mean_by_orbit(inst, data_label):
 def mean_by_file(inst, data_label):
     """Mean of data_label by orbit over Instrument.bounds
 
+    .. deprecated:: 2.2.0
+      `mean_by_file` will be removed in pysat 3.0.0, it will
+      be added to pysatSeasons
+
     Parameters
     ----------
     data_label : string
@@ -388,7 +434,7 @@ def mean_by_file(inst, data_label):
 
     """
 
-    warnings.warn(' '.join(["This function is deprecated here and will be",
+    warnings.warn(' '.join(["`mean_by_file` is deprecated here and will be",
                             "removed in pysat 3.0.0. Please use",
                             "pysatSeasons instead:"
                             "https://github.com/pysat/pysatSeasons"]),
@@ -398,6 +444,19 @@ def mean_by_file(inst, data_label):
 
 
 def _core_mean(inst, data_label, by_orbit=False, by_day=False, by_file=False):
+    """ Core mean
+
+    .. deprecated:: 2.2.0
+      Routine will be removed in pysat 3.0.0, it will be added to pysatSeasons:
+      https://github.com/pysat/pysatSeasons
+
+    """
+
+    warnings.warn(' '.join(["`_core_mean` is deprecated here and will be",
+                            "removed in pysat 3.0.0. Please use",
+                            "pysatSeasons instead:"
+                            "https://github.com/pysat/pysatSeasons"]),
+                  DeprecationWarning, stacklevel=2)
 
     if by_orbit:
         iterator = inst.orbits
@@ -434,6 +493,10 @@ def _calc_1d_median(ans, data_label, binx, xarr, zarr, numx, numz,
                     returnData=False):
     """Calculate the 1D median
 
+    .. deprecated:: 2.2.0
+      Routine will be removed in pysat 3.0.0, it will be added to pysatSeasons:
+      https://github.com/pysat/pysatSeasons
+
     Parameters
     ----------
 
@@ -446,6 +509,12 @@ def _calc_1d_median(ans, data_label, binx, xarr, zarr, numx, numz,
 
     """
 
+    warnings.warn(' '.join(["`_calc_1d_median` is deprecated here and will be",
+                            "removed in pysat 3.0.0. Please use",
+                            "pysatSeasons instead:"
+                            "https://github.com/pysat/pysatSeasons"]),
+                  DeprecationWarning, stacklevel=2)
+
     # set up output arrays
     medianAns = [[None for i in xarr] for k in zarr]
     countAns = [[None for i in xarr] for k in zarr]
