@@ -5,6 +5,7 @@ import glob
 import numpy as np
 import os
 import sys
+import warnings
 
 from nose.tools import raises
 import pandas as pds
@@ -93,11 +94,14 @@ class TestNoDataDir():
 
     def setup(self):
         """Runs before every method to create a clean testing setup."""
+        warnings.filterwarnings('ignore', category=DeprecationWarning)
         self.temporary_file_list = False
         # store current pysat directory
         self.saved_data_path = pysat.data_dir
 
-        pysat.data_dir = ''
+        # Setting pysat.data_dir directly now contains built in checks
+        # Setting the underlying ._data_dir as a bypass.
+        pysat._data_dir = ''
         re_load(pysat._files)
 
     def teardown(self):
@@ -107,6 +111,8 @@ class TestNoDataDir():
 
     @raises(Exception)
     def test_no_data_dir(self):
+
+        pysat.files.data_dir = pysat.data_dir
         _ = pysat.Instrument()
 
 
@@ -116,6 +122,7 @@ class TestBasics():
 
     def setup(self):
         """Runs before every method to create a clean testing setup."""
+        warnings.filterwarnings('ignore', category=DeprecationWarning)
         # store current pysat directory
         self.data_path = pysat.data_dir
 
@@ -378,6 +385,7 @@ class TestInstrumentWithFiles():
 
     def setup(self):
         """Runs before every method to create a clean testing setup."""
+        warnings.filterwarnings('ignore', category=DeprecationWarning)
         # store current pysat directory
         self.data_path = pysat.data_dir
         # create temporary directory
@@ -728,6 +736,7 @@ class TestInstrumentWithVersionedFiles():
 
     def setup(self):
         """Runs before every method to create a clean testing setup."""
+        warnings.filterwarnings('ignore', category=DeprecationWarning)
         # store current pysat directory
         self.data_path = pysat.data_dir
         # create temporary directory
@@ -982,3 +991,56 @@ class TestInstrumentWithVersionedFiles():
 class TestInstrumentWithVersionedFilesNoFileListStorage(TestInstrumentWithVersionedFiles):
 
     temporary_file_list = True
+
+
+class TestDeprecation():
+
+    def setup(self):
+        """Runs before every method to create a clean testing setup"""
+        warnings.simplefilter("always", DeprecationWarning)
+
+    def teardown(self):
+        """Runs after every method to clean up previous testing"""
+
+    def test_deprecation_warning_process_parsed_filenames(self):
+        """Test if _files.process_parsed_filenames is deprecated"""
+
+        with warnings.catch_warnings(record=True) as war:
+            try:
+                pysat._files.process_parsed_filenames({})
+            except KeyError:
+                # Inputting empty dict will produce KeyError
+                pass
+
+        assert len(war) >= 1
+        assert war[0].category == DeprecationWarning
+
+    def test_deprecation_warning_parse_fixed_width_filenames(self):
+        """Test if _files.parse_fixed_width_filenames is deprecated"""
+
+        with warnings.catch_warnings(record=True) as war:
+            # Empty input produces empty output
+            pysat._files.parse_fixed_width_filenames([], '')
+
+        assert len(war) >= 1
+        assert war[0].category == DeprecationWarning
+
+    def test_deprecation_warning_parse_delimited_filenames(self):
+        """Test if _files.parse_delimited_filenames is deprecated"""
+
+        with warnings.catch_warnings(record=True) as war:
+            # Empty input produces empty output
+            pysat._files.parse_delimited_filenames([], '', '')
+
+        assert len(war) >= 1
+        assert war[0].category == DeprecationWarning
+
+    def test_deprecation_warning_construct_searchstring_from_format(self):
+        """Test if _files.construct_searchstring_from_format is deprecated"""
+
+        with warnings.catch_warnings(record=True) as war:
+            # Empty input produces empty output
+            pysat._files.construct_searchstring_from_format('')
+
+        assert len(war) >= 1
+        assert war[0].category == DeprecationWarning
